summaryrefslogtreecommitdiffstats
path: root/sbin/fsdb/fsdb.c
diff options
context:
space:
mode:
authortrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
committertrhodes <trhodes@FreeBSD.org>2002-08-21 18:11:48 +0000
commit136be46680c6e4a18cc827da991d4f9a0de29cba (patch)
treeb5ee0aba66633a4e0e47097e4f383c253a87887a /sbin/fsdb/fsdb.c
parent9618da3e35435c433d8086d65af15f716ffe32ec (diff)
downloadFreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.zip
FreeBSD-src-136be46680c6e4a18cc827da991d4f9a0de29cba.tar.gz
s/filesystem/file system/g as discussed on -developers
Diffstat (limited to 'sbin/fsdb/fsdb.c')
-rw-r--r--sbin/fsdb/fsdb.c8
1 files changed, 4 insertions, 4 deletions
diff --git a/sbin/fsdb/fsdb.c b/sbin/fsdb/fsdb.c
index 9971b7c..1e91d22 100644
--- a/sbin/fsdb/fsdb.c
+++ b/sbin/fsdb/fsdb.c
@@ -65,8 +65,8 @@ char nflag;
/*
* We suck in lots of fsck code, and just pick & choose the stuff we want.
*
* fsreadfd is set up to read from the filesystem, fswritefd to write to
* the filesystem.
*/
int
main(int argc, char *argv[])
@@ -100,8 +100,8 @@ main(int argc, char *argv[])
sblock_init();
if (!setup(fsys))
- errx(1, "cannot set up filesystem `%s'", fsys);
- printf("%s filesystem `%s'\nLast Mounted on %s\n",
+ errx(1, "cannot set up file system `%s'", fsys);
+ printf("%s file system `%s'\nLast Mounted on %s\n",
nflag? "Examining": "Editing", fsys, sblock.fs_fsmnt);
rval = cmdloop();
if (!nflag) {
@@ -65,8 +65,8 @@ char nflag;
* We suck in lots of fsck code, and just pick & choose the stuff we want.
*
- * fsreadfd is set up to read from the filesystem, fswritefd to write to
- * the filesystem.
+ * fsreadfd is set up to read from the file system, fswritefd to write to
+ * the file system.
*/
int
OpenPOWER on IntegriCloud